@@ -314,11 +314,11 @@ This is useful when alternating between URLs for which auto-rules are enabled or
 disabled.  Example browsing sequence:
 
 - https://example.org (no-script-mode no-image-mode) ; No rule.
-- https://nyxt.atlas.engineer (dark-mode) ; Rule
+- https://nyxt-browser.com (dark-mode) ; Rule
 - https://en.wikipedia.org (no-script-mode no-image-mode) ; No rule.
 
-When browsing from nyxt.atlas.engineer to en.wikipedia.org, the modes that were
-enabled before nyxt.atlas.engineer are restored.")
+When browsing from nyxt-browser.com to en.wikipedia.org, the modes that were
+enabled before nyxt-browser.com are restored.")
    (enable-mode-hook
     (make-instance 'hook-mode)
     :type hook-mode
@@ -906,13 +906,12 @@ Also see `panel-page'."))
               :margin-left "-10px")
             `("#container"
               :display "flex"
-              ;; Columns: controls, url, tabs, modes
               :justify-content "space-between"
               :overflow-y "hidden")
             `("#controls"
               :background-color ,theme:secondary
               :color ,theme:on-secondary
-              :padding-left "10px"
+              :padding-left "8px"
               :overflow "hidden"
               :white-space "nowrap"
               :z-index "3"
@@ -923,10 +922,6 @@ Also see `panel-page'."))
               :margin-left "-8px")
             `("#reload"
               :width "24px !important")
-            `("#controls > button:hover"
-              :background-color ,theme:accent
-              :color ,theme:on-accent
-              :opacity "1.0")
             `("#url"
               :background-color ,theme:primary
               :color ,theme:on-primary
@@ -940,6 +935,9 @@ Also see `panel-page'."))
               :flex-grow "3"
               :flex-shrink "2"
               :flex-basis "144px")
+            `("#url button"
+              :text-align "left"
+              :width "100%")
             `("#tabs"
               :background-color ,theme:secondary
               :color ,theme:on-secondary
@@ -957,9 +955,8 @@ Also see `panel-page'."))
             `("#tabs::-webkit-scrollbar"
               :display "none")
             `(".tab"
-              :background-color ,theme:background
+              :background-color ,theme:background-
               :color ,theme:on-background
-              :opacity 0.6
               :display "inline-block"
               :margin-top "1px"
               :padding-left "18px"
@@ -972,9 +969,6 @@ Also see `panel-page'."))
               :font "inherit"
               :outline "inherit"
               :clip-path "polygon(calc(100% - 10px) 0, 100% calc(50% - 1px), 100% 50%, 100% calc(50% + 1px), calc(100% - 10px) 100%, 0% 100%, 10px calc(50% + 1px), 10px 50%, 10px calc(50% - 1px),  0% 0%)")
-            `(".tab:hover"
-              :opacity 0.8
-              :cursor "pointer")
             `("#modes"
               :background-color ,theme:primary
               :color ,theme:on-primary
@@ -995,18 +989,16 @@ Also see `panel-page'."))
               :padding 0
               :font "inherit"
               :outline "inherit")
-            `(.button.action
+            `((:and (:or .button .tab "#url") :hover)
+              :cursor "pointer"
               :background-color ,theme:action
               :color ,theme:on-action)
-            `((:and .button :hover)
-              :cursor "pointer"
-              :opacity 0.6)
-            `((:and .button (:or :visited :active))
-              :color ,theme:background)
+            `((:and (:or .button .tab) :active)
+              :background-color ,theme:action-
+              :color ,theme:on-action)
             `(.selected-tab
-              :color ,theme:on-background
-              :opacity "1.0 !important"
-              :background-color ,theme:background))))
+              :background-color ,theme:background+
+              :color ,theme:on-background))))
   (:export-class-name-p t)
   (:export-accessor-names-p t)
   (:export-predicate-name-p t)
@@ -1450,9 +1442,10 @@ buffer currently chosen as suggestion."))
 
 (define-command switch-buffer (&key buffer (current-is-last-p nil))
   "Switch buffer using fuzzy completion.
-Buffers are ordered by last access.
-With CURRENT-IS-LAST-P, the current buffer is listed last so as to list the
-second latest buffer first."
+
+Buffers are ordered by most recent access time.  When CURRENT-IS-LAST-P is
+non-nil, the current buffer is listed last so that the last visited buffer
+is listed first."
   (if buffer
       (set-current-buffer buffer)
       (prompt
@@ -1462,7 +1455,7 @@ second latest buffer first."
                                              :current-is-last-p current-is-last-p)))))
 
 (define-command switch-buffer-domain (&key domain (buffer (current-buffer)))
-  "Switch the active buffer in the current window from the current domain."
+  "Switch to buffer sharing the same domain as the current one."
   (let ((domain (or domain (quri:uri-domain (url buffer)))))
     (prompt
      :prompt "Switch to buffer in current domain"
@@ -1998,12 +1991,10 @@ When there is no next buffer, go to the first one so as to cycle."
 
 (define-command switch-buffer-last ()
   "Switch to the last visited buffer.
-That is, the one with the most recent access time.
 
-Return this last buffer."
-  (let* ((buffers (sort-by-time (buffer-list))))
-    (when (second buffers)
-      (set-current-buffer (second buffers)))))
+The buffer with the most recent access time is returned."
+  (alex:when-let ((buffer (second (sort-by-time (buffer-list)))))
+    (set-current-buffer buffer)))
 
 (define-command open-inspector ()
   "Open the inspector, a graphical tool to inspect and change the buffer's content."
