@@ -908,3 +908,18 @@ Nyxt version exists.  It is only raised when the major version differs.")
      (:li "Fix command "
           (:nxref :command 'nyxt/mode/prompt-buffer:toggle-attributes-display)
           " and behavior of UI elements relying on it."))))
+
+(define-version "3.9.2"
+  (:nsection :title "UI/UX"
+    (:ul
+     (:li "Review of the status buffer UI.  The URL area is now clickable.")))
+  (:nsection :title "Bug fixes"
+    (:ul
+     (:li (:nxref :mode 'nyxt/mode/blocker:blocker-mode)
+          " ensures that hostlist files are loaded when missing.")
+     (:li "Fix connection to Nyxt via commands "
+          (:code "start-swank") " and " (:code "start-slynk") ".")))
+  (:nsection :title "Programming interface"
+    (:ul
+     (:li "When running Nyxt as a Flatpak, programs available on the host can be
+invoked via " (:code "flatpak-spawn --host <command> <command-args>") "."))))
