@@ -105,7 +105,10 @@ internal programming APIs."
     '()
     :type (list-of string)))
   (:export-class-name-p t)
-  (:export-accessor-names-p t))
+  (:export-accessor-names-p t)
+  (:documentation "Represents Nyxt bookmark.
+`url' is the identity of the `bookmark-entry', used in `equals'.
+`title', `annotation', `date', `tags' are useful pieces of metadata."))
 
 (defmethod prompter:object-attributes ((entry bookmark-entry) (source prompter:source))
   (declare (ignore source))
@@ -114,17 +117,24 @@ internal programming APIs."
     ("Tags" ,(format nil "~{~a ~}" (tags entry)))
     ("Date" ,(local-time:format-timestring nil (date entry) :format local-time:+asctime-format+))))
 
-(export-always 'equals)
-(defmethod equals ((e1 bookmark-entry) (e2 bookmark-entry))
-  "Entries are equal if the hosts and the paths are equal.
+;; FIXME: Move somewhere else, where Nyxt-global function declarations belong?
+(define-generic equals (object1 object2)
+  "Nyxt-specific equality function."
+  (:method ((e1 bookmark-entry) (e2 bookmark-entry))
+    "Entries are equal if the hosts and the paths are equal.
 In particular, we ignore the protocol (e.g. HTTP or HTTPS does not matter)."
-  (url-equal (url e1) (url e2)))
+    (url-equal (url e1) (url e2)))
+  (:export-generic-name-p t))
 
 (-> bookmark-add
     (quri:uri &key (:title string) (:date (or time:timestamp null)) (:tags t))
     t)
 (export-always 'bookmark-add)
 (defun bookmark-add (url &key date title tags)
+  "Store the bookmark for URL in `bookmarks-file' of the current buffer.
+Creates a `bookmark-entry' with DATE, TITLE, and TAGS, when provided.
+If there's a bookmarks with the same URL, update the TITLE, TAGS, and DATE
+instead."
   (files:with-file-content (bookmarks (bookmarks-file (current-buffer)))
     (unless (or (url-empty-p url)
                 (string= "about:blank" (render-url url)))
@@ -150,8 +160,13 @@ In particular, we ignore the protocol (e.g. HTTP or HTTPS does not matter)."
   ((prompter:name "Bookmarks")
    (prompter:constructor (files:content (bookmarks-file (current-buffer))))
    (prompter:enable-marks-p t)
-   (prompter:active-attributes-keys '("URL" "Title" "Tags")))
-  (:export-class-name-p t))
+   (prompter:active-attributes-keys
+    '("URL" "Title" "Tags")
+    :accessor nil))
+  (:export-class-name-p t)
+  (:documentation "Source for bookmark search.
+By default, matches URL, title, and tags of the bookmark, but can also match
+against date, given `prompter:active-attributes-keys' configuration."))
 
 (defmethod url-sources ((mode bookmark-mode) actions-on-return)
   (make-instance 'bookmark-source :actions-on-return actions-on-return))
@@ -184,26 +199,27 @@ In particular, we ignore the protocol (e.g. HTTP or HTTPS does not matter)."
 (define-panel-command-global bookmarks-panel ()
     (panel-buffer "*Bookmarks panel*")
   "Shows all the bookmarks in a compact panel-buffer layout."
-  (spinneret:with-html-string
-    (:nstyle
-      '(p
-        :font-size "12px"
-        :margin 0
-        :white-space nowrap
-        :overflow-x hidden
-        :text-overflow ellipsis)
-      '(div
-        :padding-bottom "10px"))
-    (:body
-     (:h1 "Bookmarks")
-     (or (let ((bookmarks (files:content (bookmarks-file (current-buffer)))))
-           (loop for bookmark in bookmarks
-                 collect
-                 (let ((url-href (render-url (url bookmark))))
-                   (:div
-                    (:p (title bookmark))
-                    (:p (:a :href url-href :target "_blank" url-href))))))
-         (format nil "No bookmarks in ~s." (files:expand (files:content (bookmarks-file (current-buffer)))))))))
+  (let ((bookmarks (group-bookmarks (current-buffer))))
+    ;; Simplified version of list-bookmarks
+    (spinneret:with-html-string
+      (:body
+       (:h1 "Bookmarks")
+       (if (zerop (hash-table-count bookmarks))
+           (:p (format nil "No bookmarks in ~s."
+                       (files:expand (files:content (bookmarks-file (current-buffer))))))
+           (maphash (lambda (tag bookmarks)
+                      (:nsection
+                        :title (or tag "Unsorted")
+                        :id (or tag "unsorted")
+                        :open-p t
+                        (dolist (bookmark bookmarks)
+                          (:dl (:dt (:a :href (render-url (url bookmark))
+                                        :target "_blank"
+                                        (title bookmark)))
+                               (when (tags bookmark)
+                                 (:dd (format nil "Tags: ~{~a~^, ~}" (tags bookmark)))))
+                          (:hr))))
+                    bookmarks))))))
 
 (export-always 'url-bookmark-tags)
 (defun url-bookmark-tags (url)
@@ -323,8 +339,7 @@ Splits bookmarks into groups by tags."
                 :id (or tag "unsorted")
                 :open-p nil
                 (dolist (bookmark bookmarks)
-                  (let ((uri-host (quri:uri-host (url bookmark)))
-                        (url-href (render-url (url bookmark))))
+                  (let ((url-href (render-url (url bookmark))))
                     (lisp-url-flet bookmarks-buffer
                         ((delbkm (&key href)
                            (delete-bookmark href)))
@@ -340,10 +355,9 @@ Splits bookmarks into groups by tags."
                                                             :buffer bookmarks-buffer
                                                             :args (:href url-href)))
                                        "✕")
-                              (serapeum:ellipsize (title bookmark) 80))
-                             (:dd (:a :href url-href uri-host))
+                              (:a :href url-href (title bookmark)))
                              (when (tags bookmark)
-                               (:dd (format nil " (~{~a~^, ~})" (tags bookmark)))))
+                               (:dd (format nil "Tags: ~{~a~^, ~}" (tags bookmark)))))
                             (:hr)))))))
             bookmarks))))))
 
