@@ -312,34 +312,22 @@ See also `show-prompt-buffer'."
           (show-prompt-buffer next-prompt-buffer))
         (setf (ffi-height prompt-buffer) 0))))
 
-(defun suggestion-and-mark-count (prompt-buffer suggestions marks
-                                  &key enable-marks-p pad-p)
+(defun suggestion-and-mark-count (prompt-buffer suggestions marks &key enable-marks-p pad-p)
   (alex:maxf (max-suggestions prompt-buffer)
              (length suggestions))
-  (labels ((decimals (n)
-             (cond
-               ((< n 0)
-                (decimals (- n)))
-               ((< n 10)
-                1)
-               (t (1+ (decimals (truncate n 10)))))))
-    (cond
-      ((not suggestions)
-       "")
-      ((hide-suggestion-count-p prompt-buffer)
-       "")
-      (t
-       (let ((padding (if pad-p
-                          (prin1-to-string (decimals (max-suggestions prompt-buffer)))
-                          "0")))
-         (format nil (str:concat "[~a~" padding ",,,' @a]")
-                 (cond
-                   ((or marks enable-marks-p)
-                    (format nil
-                            (str:concat "~" padding ",,,' @a/")
-                            (length marks)))
-                   (t ""))
-                 (length suggestions)))))))
+  (flet ((digits-count (n) (1+ (floor (log (abs n) 10)))))
+    (if (or (not suggestions)
+            (hide-suggestion-count-p prompt-buffer))
+        ""
+        (let ((padding (if pad-p
+                           (prin1-to-string (digits-count (max-suggestions prompt-buffer)))
+                           "0")))
+          (format nil
+                  (str:concat "[~a~" padding ",,,' @a]")
+                  (if (or marks enable-marks-p)
+                      (format nil (str:concat "~" padding ",,,' @a/") (length marks))
+                      "")
+                  (length suggestions))))))
 
 (defun prompt-render-prompt (prompt-buffer)
   (let* ((suggestions (prompter:all-suggestions prompt-buffer))
@@ -354,7 +342,7 @@ See also `show-prompt-buffer'."
               prompt-buffer suggestions marks
               :pad-p t
               :enable-marks-p (some #'prompter:enable-marks-p
-                                       (prompter:sources prompt-buffer)))))
+                                    (prompter:sources prompt-buffer)))))
       (setf (ps:@ (nyxt/ps:qs document "#prompt-modes") |innerHTML|)
             (ps:lisp (str:join " "
                                (mapcar (curry #'mode-status status-buffer)
@@ -599,7 +587,8 @@ If you want to set the input, see `set-prompt-buffer-input'."
     (setf (prompter:input prompt-buffer) input)
     ;; TODO: Stop loop when prompt-buffer is no longer current.
     (labels ((maybe-update-view ()
-               (let ((next-source (when (find prompt-buffer (active-prompt-buffers (window prompt-buffer)))
+               (let ((next-source (when (find prompt-buffer
+                                              (active-prompt-buffers (window prompt-buffer)))
                                     (prompter:next-ready-p prompt-buffer))))
                  (cond
                    ;; Nothing to do:
